Приложение B. Описание команд jabber-бота
Пред. |  |

## Приложение B. Описание команд jabber-бота

admins

  Выводит список администраторов. Учитываются администраторы, указанные в конфигурационном файле, и пользователи, наиболее активно голосовавшие (если эта функция включена).

download `имя исполнителя`

  Ищет свободно распространяемые композиции указанного исполнителя в Last.fm и Jamendo и загружает 3 штуки. Если в медиатеке уже есть композиции указанного исполнителя — сообщает об этом и ничего не загружает.

  Пример B.1. Загрузка музыки из открытых источников

      > download cool music
      Это займёт какое-то время, я сообщу о результате.
      Could not find anything by "cool music" on Last.fm and Jamendo.

find `поисковый_запрос`

  Выводит список композиций, содержащих указанную строку.

news

  Выводит список последних 10 загруженных композиций, например:

      Recently added tracks:
      «Песня идущего домой» by Ю-Питер — #6899 ⚖1.00 ♺0
      «Девушка по городу» by Ю-Питер — #6898 ⚖1.00 ♺0
      «Эта музыка будет вечной» by Ю-Питер — #6897 ⚖1.00 ♺0

play [--time=время] `метки`

  Включает виртуальный плейлист из указанных меток на указанное время (60 минут по умолчанию).

  Пример B.2. Создание плейлиста на ходу

      > play @lounge @+instrumental @-ambient
      OK.

  При этом в чат отправляется такое сообщение:

      Playlist for next 60 minutes: @lounge.

  Отмена созданного плейлиста:

      > play all
      OK.

queue [флаги] `поисковый_запрос`

  Добавляет в очередь композиции, удовлетворяющие запросу.

restart

  Перезапускает робота. Обычно эта команда используется после внесения изменений в конфигурационный файл. Если доступа к роботу нет, в системе Debian/Ubuntu это можно сделать командой:

      sudo restart ardj-jabber

rocks [`track_id`]

  Добавляет голос в пользу указанной (или текущей) композиции, увеличивая её рейтинг.

speak `текст`

  Преобразует текст в голос и заряжает в очередь проигрывания. Работает только если настроен синтезатор речи.

sucks [`track_id`]

  Добавляет голос против указанной (или текущей) композиции, уменьшая её рейтинг.

tags `-old +new` [for `track_id`]

  Изменяет метки композиции. Метки используются для привязки композиций к плейлистам. Изменения вступают в силу незамедлительно.

  Пример B.3. Изменение меток композиции

      > find @tagme
      Found 63 tracks, showing 10:
      «Neon» by Denergized — #4935 ⚖1.20 ♺4 @tagme
      > tags -tagme industrial vocals for 4935
      New labels: industrial, vocals.
      > tags -tagme rock --artist=KMFDM
      > tags -calm live --filename="%/KMFDM (Live)/%"

Пред. |  |
Приложение A. Описание параметров командной строки | Начало |